You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@deltaspike.apache.org by gp...@apache.org on 2012/04/08 01:48:35 UTC

git commit: DELTASPIKE-152 unified package names

Updated Branches:
  refs/heads/master ca90b1cc1 -> dd355a2ba


DELTASPIKE-152 unified package names


Project: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/commit/dd355a2b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/tree/dd355a2b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/diff/dd355a2b

Branch: refs/heads/master
Commit: dd355a2ba89c2df6d7caade6bf3d7283ff4b9dcb
Parents: ca90b1c
Author: gpetracek <gp...@apache.org>
Authored: Sun Apr 8 01:33:15 2012 +0200
Committer: gpetracek <gp...@apache.org>
Committed: Sun Apr 8 01:36:27 2012 +0200

----------------------------------------------------------------------
 .../deltaspike/core/api/config/ConfigProperty.java |   49 -------
 .../core/api/config/annotation/ConfigProperty.java |   49 +++++++
 .../deltaspike/core/api/exclude/Exclude.java       |  105 ---------------
 .../core/api/exclude/annotation/Exclude.java       |  105 +++++++++++++++
 .../api/interpreter/ExpressionInterpreter.java     |    2 +-
 .../core/api/literal/MessageBundleLiteral.java     |    2 +-
 .../api/literal/MessageContextConfigLiteral.java   |    4 +-
 .../deltaspike/core/api/message/Message.java       |   39 ------
 .../deltaspike/core/api/message/MessageBundle.java |   36 -----
 .../core/api/message/MessageContextConfig.java     |   38 -----
 .../core/api/message/annotation/Message.java       |   39 ++++++
 .../core/api/message/annotation/MessageBundle.java |   36 +++++
 .../message/annotation/MessageContextConfig.java   |   42 ++++++
 .../impl/config/injectable/ConfigPropertyBean.java |    2 +-
 .../config/injectable/ConfigPropertyExtension.java |    4 +-
 .../config/injectable/InjectionTargetEntry.java    |    2 +-
 .../core/impl/exclude/ExcludeExtension.java        |    6 +-
 .../core/impl/message/MessageBundleExtension.java  |    2 +-
 .../message/MessageBundleInvocationHandler.java    |    4 +-
 .../CustomConfigAnnotationWithMetaData.java        |    2 +-
 ...gAnnotationWithMetaDataWithCustomConverter.java |    2 +-
 .../core/api/config/injectable/SettingsBean.java   |    2 +-
 .../injectable/SimpleCustomConfigAnnotation.java   |    2 +-
 .../api/exclude/CustomExpressionBasedBean.java     |    2 +-
 .../api/exclude/CustomExpressionBasedNoBean.java   |    2 +-
 .../deltaspike/test/core/api/exclude/DevBean.java  |    2 +-
 .../test/core/api/exclude/DevDbBean.java           |    2 +-
 .../test/core/api/exclude/ExcludeTest.java         |    2 +-
 .../ExcludeTestProjectStageDevelopment.java        |    2 +-
 .../deltaspike/test/core/api/exclude/NoBean.java   |    2 +-
 .../test/core/api/exclude/ProdDbBean.java          |    2 +-
 .../deltaspike/test/core/api/exclude/StdBean.java  |    2 +-
 .../test/core/api/message/MessageTest.java         |    2 +-
 .../test/core/api/message/SimpleMessage.java       |    6 +-
 .../test/core/api/message/SimpleMessageTest.java   |    2 +-
 .../test/core/api/message/TestMessages.java        |    9 +-
 .../core/api/exclude/ExcludeIntegrationTest.java   |    2 +-
 .../core/api/exclude/IntegrationTestBean.java      |    2 +-
 .../core/api/exclude/IntegrationTestDbBean.java    |    2 +-
 .../deltaspike/example/config/Property2.java       |    2 +-
 .../config/Property2WithInverseSupport.java        |    2 +-
 .../deltaspike/example/config/SettingsBean.java    |    2 +-
 .../deltaspike/example/echo/NoEchoService.java     |    2 +-
 .../impl/authentication/InMemoryUserStorage.java   |    2 +-
 44 files changed, 318 insertions(+), 309 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/ConfigProperty.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/ConfigProperty.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/ConfigProperty.java
deleted file mode 100644
index ed5e612..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/ConfigProperty.java
+++ /dev/null
@@ -1,49 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.deltaspike.core.api.config;
-
-import org.apache.deltaspike.core.api.converter.Converter;
-
-import javax.enterprise.util.Nonbinding;
-import javax.inject.Qualifier;
-import java.lang.annotation.Documented;
-import java.lang.annotation.Retention;
-import java.lang.annotation.Target;
-
-import static java.lang.annotation.ElementType.CONSTRUCTOR;
-import static java.lang.annotation.ElementType.FIELD;
-import static java.lang.annotation.ElementType.METHOD;
-import static java.lang.annotation.ElementType.PARAMETER;
-import static java.lang.annotation.ElementType.ANNOTATION_TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-@Target({ PARAMETER, FIELD, METHOD, CONSTRUCTOR, ANNOTATION_TYPE })
-@Retention(RUNTIME)
-@Documented
-
-@Qualifier
-public @interface ConfigProperty
-{
-    String name();
-
-    @Nonbinding
-    Class<? extends Converter> converter() default Converter.class;
-
-    boolean eager() default true;
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/annotation/ConfigProperty.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/annotation/ConfigProperty.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/annotation/ConfigProperty.java
new file mode 100644
index 0000000..a1bfdda
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/config/annotation/ConfigProperty.java
@@ -0,0 +1,49 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.deltaspike.core.api.config.annotation;
+
+import org.apache.deltaspike.core.api.converter.Converter;
+
+import javax.enterprise.util.Nonbinding;
+import javax.inject.Qualifier;
+import java.lang.annotation.Documented;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+import static java.lang.annotation.ElementType.CONSTRUCTOR;
+import static java.lang.annotation.ElementType.FIELD;
+import static java.lang.annotation.ElementType.METHOD;
+import static java.lang.annotation.ElementType.PARAMETER;
+import static java.lang.annotation.ElementType.ANNOTATION_TYPE;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+@Target({ PARAMETER, FIELD, METHOD, CONSTRUCTOR, ANNOTATION_TYPE })
+@Retention(RUNTIME)
+@Documented
+
+@Qualifier
+public @interface ConfigProperty
+{
+    String name();
+
+    @Nonbinding
+    Class<? extends Converter> converter() default Converter.class;
+
+    boolean eager() default true;
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/Exclude.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/Exclude.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/Exclude.java
deleted file mode 100644
index da2803b..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/Exclude.java
+++ /dev/null
@@ -1,105 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.deltaspike.core.api.exclude;
-
-import org.apache.deltaspike.core.api.interpreter.ExpressionInterpreter;
-import org.apache.deltaspike.core.api.projectstage.ProjectStage;
-
-import java.lang.annotation.ElementType;
-import java.lang.annotation.Retention;
-import java.lang.annotation.RetentionPolicy;
-import java.lang.annotation.Target;
-
-/**
- * Supported usages:
- * <pre>
- * @Exclude
- * @Exclude(ifProjectStage=Production.class)
- * @Exclude(exceptIfProjectStage=UnitTest.class)
- * @Exclude(onExpression="myProperty==myValue")
- * @Exclude(onExpression="[my custom expression syntax]", interpretedBy=CustomExpressionInterpreter.class)
- * </pre>
- *
- * <p/>
- * examples:
- * <p/>
- * <p>the following bean gets excluded in any case</p>
- * <pre>
- * @Exclude
- * public class NoBean {}
- * </pre>
- *
- * <p/>
- * <p>the following bean gets excluded in case of project-stage development</p>
- * <pre>
- * @Exclude(ifProjectStage = ProjectStage.Development.class)
- * public class ProductionBean {}
- * </pre>
- *
- * <p/>
- * <p>the following bean gets excluded in every case except of project-stage development</p>
- * <pre>
- * @Exclude(exceptIfProjectStage = ProjectStage.Development.class)
- * public class DevBean {}
- * </pre>
- *
- * <p/>
- * <p>the following bean gets excluded if the expression evaluates to true.
- * that means there is a configured property called 'myProper' with the value 'myValue'</p>
- * <pre>
- * @Exclude(onExpression="myProperty==myValue")
- * public class ProductionBean {}
- * </pre>
- *
- * <p/>
- * <p>the following bean gets excluded if the expression evaluates to true</p>
- * @Exclude(onExpression="[my custom expression syntax]", interpretedBy=CustomExpressionInterpreter.class)
- * public class ProductionBean {}
- */
-@Retention(RetentionPolicy.RUNTIME)
-@Target({ ElementType.TYPE })
-public @interface Exclude
-{
-    /**
-     * The {@link org.apache.deltaspike.core.api.projectstage.ProjectStage}s
-     * which lead to deactivating this bean.
-     * If the current ProjectStage is in this list, the bean will get vetoed.
-     * @return 1-n project-stages which are not allowed for the annotated artifact
-     */
-    Class<? extends ProjectStage>[] ifProjectStage() default { };
-
-    /**
-     * The {@link org.apache.deltaspike.core.api.projectstage.ProjectStage}s
-     * which lead to activating this bean.
-     * If the current ProjectStage is not in this list, the bean will get vetoed.
-     * @return 1-n project-stages which are allowed for the annotated artifact
-     */
-    Class<? extends ProjectStage>[] exceptIfProjectStage() default { };
-
-    /**
-     * Expression which signals if the annotated bean should be deactivated or not
-     * @return expression-string which will be interpreted
-     */
-    String onExpression() default "";
-
-    /**
-     * @return class of the interpeter which should be used (default leads to a simple config-property interpreter)
-     */
-    Class<? extends ExpressionInterpreter> interpretedBy() default ExpressionInterpreter.class;
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/annotation/Exclude.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/annotation/Exclude.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/annotation/Exclude.java
new file mode 100644
index 0000000..a12559c
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exclude/annotation/Exclude.java
@@ -0,0 +1,105 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.deltaspike.core.api.exclude.annotation;
+
+import org.apache.deltaspike.core.api.interpreter.ExpressionInterpreter;
+import org.apache.deltaspike.core.api.projectstage.ProjectStage;
+
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
+
+/**
+ * Supported usages:
+ * <pre>
+ * @Exclude
+ * @Exclude(ifProjectStage=Production.class)
+ * @Exclude(exceptIfProjectStage=UnitTest.class)
+ * @Exclude(onExpression="myProperty==myValue")
+ * @Exclude(onExpression="[my custom expression syntax]", interpretedBy=CustomExpressionInterpreter.class)
+ * </pre>
+ *
+ * <p/>
+ * examples:
+ * <p/>
+ * <p>the following bean gets excluded in any case</p>
+ * <pre>
+ * @Exclude
+ * public class NoBean {}
+ * </pre>
+ *
+ * <p/>
+ * <p>the following bean gets excluded in case of project-stage development</p>
+ * <pre>
+ * @Exclude(ifProjectStage = ProjectStage.Development.class)
+ * public class ProductionBean {}
+ * </pre>
+ *
+ * <p/>
+ * <p>the following bean gets excluded in every case except of project-stage development</p>
+ * <pre>
+ * @Exclude(exceptIfProjectStage = ProjectStage.Development.class)
+ * public class DevBean {}
+ * </pre>
+ *
+ * <p/>
+ * <p>the following bean gets excluded if the expression evaluates to true.
+ * that means there is a configured property called 'myProper' with the value 'myValue'</p>
+ * <pre>
+ * @Exclude(onExpression="myProperty==myValue")
+ * public class ProductionBean {}
+ * </pre>
+ *
+ * <p/>
+ * <p>the following bean gets excluded if the expression evaluates to true</p>
+ * @Exclude(onExpression="[my custom expression syntax]", interpretedBy=CustomExpressionInterpreter.class)
+ * public class ProductionBean {}
+ */
+@Retention(RetentionPolicy.RUNTIME)
+@Target({ ElementType.TYPE })
+public @interface Exclude
+{
+    /**
+     * The {@link org.apache.deltaspike.core.api.projectstage.ProjectStage}s
+     * which lead to deactivating this bean.
+     * If the current ProjectStage is in this list, the bean will get vetoed.
+     * @return 1-n project-stages which are not allowed for the annotated artifact
+     */
+    Class<? extends ProjectStage>[] ifProjectStage() default { };
+
+    /**
+     * The {@link org.apache.deltaspike.core.api.projectstage.ProjectStage}s
+     * which lead to activating this bean.
+     * If the current ProjectStage is not in this list, the bean will get vetoed.
+     * @return 1-n project-stages which are allowed for the annotated artifact
+     */
+    Class<? extends ProjectStage>[] exceptIfProjectStage() default { };
+
+    /**
+     * Expression which signals if the annotated bean should be deactivated or not
+     * @return expression-string which will be interpreted
+     */
+    String onExpression() default "";
+
+    /**
+     * @return class of the interpeter which should be used (default leads to a simple config-property interpreter)
+     */
+    Class<? extends ExpressionInterpreter> interpretedBy() default ExpressionInterpreter.class;
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/interpreter/ExpressionInterpreter.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/interpreter/ExpressionInterpreter.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/interpreter/ExpressionInterpreter.java
index a86bb6a..0e56781 100644
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/interpreter/ExpressionInterpreter.java
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/interpreter/ExpressionInterpreter.java
@@ -20,7 +20,7 @@ package org.apache.deltaspike.core.api.interpreter;
 
 /**
  * Interface for interpreting an expression e.g. provided by
- * {@link org.apache.deltaspike.core.api.exclude.Exclude#onExpression()}
+ * {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude#onExpression()}
  */
 public interface ExpressionInterpreter<E, R>
 {

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageBundleLiteral.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageBundleLiteral.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageBundleLiteral.java
index e2a3aff..933adbc 100644
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageBundleLiteral.java
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageBundleLiteral.java
@@ -20,7 +20,7 @@ package org.apache.deltaspike.core.api.literal;
 
 import javax.enterprise.util.AnnotationLiteral;
 
-import org.apache.deltaspike.core.api.message.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
 
 /**
  * Literal for {@link MessageBundle}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageContextConfigLiteral.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageContextConfigLiteral.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageContextConfigLiteral.java
index 13cfda7..bd32933 100644
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageContextConfigLiteral.java
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/MessageContextConfigLiteral.java
@@ -19,14 +19,14 @@
 package org.apache.deltaspike.core.api.literal;
 
 import org.apache.deltaspike.core.api.message.LocaleResolver;
-import org.apache.deltaspike.core.api.message.MessageContextConfig;
+import org.apache.deltaspike.core.api.message.annotation.MessageContextConfig;
 import org.apache.deltaspike.core.api.message.MessageInterpolator;
 import org.apache.deltaspike.core.api.message.MessageResolver;
 
 import javax.enterprise.util.AnnotationLiteral;
 
 /**
- * Literal for {@link org.apache.deltaspike.core.api.message.MessageContextConfig}
+ * Literal for {@link org.apache.deltaspike.core.api.message.annotation.MessageContextConfig}
  */
 public class MessageContextConfigLiteral extends AnnotationLiteral<MessageContextConfig> implements MessageContextConfig
 {

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/Message.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/Message.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/Message.java
deleted file mode 100644
index 3b1f832..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/Message.java
+++ /dev/null
@@ -1,39 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.deltaspike.core.api.message;
-
-import java.lang.annotation.Documented;
-import java.lang.annotation.Retention;
-import java.lang.annotation.Target;
-
-import static java.lang.annotation.ElementType.METHOD;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-@Target(METHOD)
-@Retention(RUNTIME)
-@Documented
-public @interface Message
-{
-    /**
-     * The default format string of this message.
-     *
-     * @return the format string
-     */
-    String value();
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageBundle.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageBundle.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageBundle.java
deleted file mode 100644
index 055709a..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageBundle.java
+++ /dev/null
@@ -1,36 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.deltaspike.core.api.message;
-
-import java.lang.annotation.Documented;
-import java.lang.annotation.Retention;
-import java.lang.annotation.Target;
-
-import static java.lang.annotation.ElementType.FIELD;
-import static java.lang.annotation.ElementType.METHOD;
-import static java.lang.annotation.ElementType.PARAMETER;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-@Target({ TYPE, METHOD, PARAMETER, FIELD })
-@Retention(RUNTIME)
-@Documented
-public @interface MessageBundle
-{
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageContextConfig.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageContextConfig.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageContextConfig.java
deleted file mode 100644
index 499d441..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/MessageContextConfig.java
+++ /dev/null
@@ -1,38 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.deltaspike.core.api.message;
-
-import java.lang.annotation.Documented;
-import java.lang.annotation.Retention;
-import java.lang.annotation.Target;
-
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-@Target({ TYPE })
-@Retention(RUNTIME)
-@Documented
-public @interface MessageContextConfig
-{
-    Class<? extends MessageResolver> messageResolver() default MessageResolver.class;
-
-    Class<? extends MessageInterpolator> messageInterpolator() default MessageInterpolator.class;
-
-    Class<? extends LocaleResolver> localeResolver() default LocaleResolver.class;
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/Message.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/Message.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/Message.java
new file mode 100644
index 0000000..8c3130c
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/Message.java
@@ -0,0 +1,39 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.deltaspike.core.api.message.annotation;
+
+import java.lang.annotation.Documented;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+import static java.lang.annotation.ElementType.METHOD;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+@Target(METHOD)
+@Retention(RUNTIME)
+@Documented
+public @interface Message
+{
+    /**
+     * The default format string of this message.
+     *
+     * @return the format string
+     */
+    String value();
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageBundle.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageBundle.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageBundle.java
new file mode 100644
index 0000000..90da537
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageBundle.java
@@ -0,0 +1,36 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.deltaspike.core.api.message.annotation;
+
+import java.lang.annotation.Documented;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+import static java.lang.annotation.ElementType.FIELD;
+import static java.lang.annotation.ElementType.METHOD;
+import static java.lang.annotation.ElementType.PARAMETER;
+import static java.lang.annotation.ElementType.TYPE;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+@Target({ TYPE, METHOD, PARAMETER, FIELD })
+@Retention(RUNTIME)
+@Documented
+public @interface MessageBundle
+{
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageContextConfig.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageContextConfig.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageContextConfig.java
new file mode 100644
index 0000000..d9456dc
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/message/annotation/MessageContextConfig.java
@@ -0,0 +1,42 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.deltaspike.core.api.message.annotation;
+
+import org.apache.deltaspike.core.api.message.LocaleResolver;
+import org.apache.deltaspike.core.api.message.MessageInterpolator;
+import org.apache.deltaspike.core.api.message.MessageResolver;
+
+import java.lang.annotation.Documented;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+import static java.lang.annotation.ElementType.TYPE;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+@Target({ TYPE })
+@Retention(RUNTIME)
+@Documented
+public @interface MessageContextConfig
+{
+    Class<? extends MessageResolver> messageResolver() default MessageResolver.class;
+
+    Class<? extends MessageInterpolator> messageInterpolator() default MessageInterpolator.class;
+
+    Class<? extends LocaleResolver> localeResolver() default LocaleResolver.class;
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyBean.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyBean.java
index d302776..d2ff12e 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyBean.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyBean.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.core.impl.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 import org.apache.deltaspike.core.api.config.ConfigResolver;
 import org.apache.deltaspike.core.api.converter.Converter;
 import org.apache.deltaspike.core.api.converter.MetaDataAwareConverter;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyExtension.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyExtension.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyExtension.java
index ff3e3aa..edfb044 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyExtension.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/ConfigPropertyExtension.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.core.impl.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 import org.apache.deltaspike.core.api.config.ConfigResolver;
 import org.apache.deltaspike.core.spi.activation.Deactivatable;
 import org.apache.deltaspike.core.util.ClassDeactivationUtils;
@@ -34,7 +34,7 @@ import java.util.HashSet;
 import java.util.Set;
 
 /**
- * Adds support for {@link org.apache.deltaspike.core.api.config.ConfigProperty}
+ * Adds support for {@link org.apache.deltaspike.core.api.config.annotation.ConfigProperty}
  */
 public class ConfigPropertyExtension implements Extension, Deactivatable
 {

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/InjectionTargetEntry.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/InjectionTargetEntry.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/InjectionTargetEntry.java
index 025a683..0dd9278 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/InjectionTargetEntry.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/config/injectable/InjectionTargetEntry.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.core.impl.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exclude/ExcludeExtension.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleExtension.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleExtension.java
index 51ad0b6..f832fba 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleExtension.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleExtension.java
@@ -33,7 +33,7 @@ import javax.enterprise.inject.spi.Extension;
 import javax.enterprise.inject.spi.ProcessAnnotatedType;
 import javax.enterprise.inject.spi.ProcessProducerMethod;
 
-import org.apache.deltaspike.core.api.message.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
 import org.apache.deltaspike.core.spi.activation.Deactivatable;
 import org.apache.deltaspike.core.util.ClassDeactivationUtils;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleInvocationHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleInvocationHandler.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleInvocationHandler.java
index c106c7c..7fb8f87 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleInvocationHandler.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleInvocationHandler.java
@@ -20,8 +20,8 @@ package org.apache.deltaspike.core.impl.message;
 
 import org.apache.deltaspike.core.api.literal.MessageContextConfigLiteral;
 import org.apache.deltaspike.core.api.message.LocaleResolver;
-import org.apache.deltaspike.core.api.message.Message;
-import org.apache.deltaspike.core.api.message.MessageContextConfig;
+import org.apache.deltaspike.core.api.message.annotation.Message;
+import org.apache.deltaspike.core.api.message.annotation.MessageContextConfig;
 import org.apache.deltaspike.core.api.message.MessageInterpolator;
 import org.apache.deltaspike.core.api.message.MessageResolver;
 import org.apache.deltaspike.core.api.provider.BeanProvider;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaData.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaData.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaData.java
index ee8399e..9e7f3cc 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaData.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaData.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.test.core.api.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.util.Nonbinding;
 import javax.inject.Qualifier;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaDataWithCustomConverter.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaDataWithCustomConverter.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaDataWithCustomConverter.java
index 85ecdfb..9400e9b 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaDataWithCustomConverter.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/CustomConfigAnnotationWithMetaDataWithCustomConverter.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.test.core.api.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.util.Nonbinding;
 import javax.inject.Qualifier;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SettingsBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SettingsBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SettingsBean.java
index 5c49f0a..a47fb3e 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SettingsBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SettingsBean.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.test.core.api.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SimpleCustomConfigAnnotation.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SimpleCustomConfigAnnotation.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SimpleCustomConfigAnnotation.java
index def40d8..cf9f97b 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SimpleCustomConfigAnnotation.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/config/injectable/SimpleCustomConfigAnnotation.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.test.core.api.config.injectable;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.inject.Qualifier;
 import java.lang.annotation.Documented;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedBean.java
index 81a5af9..2348314 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Bean won't be excluded

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedNoBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedNoBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedNoBean.java
index dc2514e..5af64a1 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedNoBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/CustomExpressionBasedNoBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Bean wil be excluded

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevBean.java
index 3b3c446..c777639 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 import org.apache.deltaspike.core.api.projectstage.ProjectStage;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevDbBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevDbBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevDbBean.java
index 92570ff..e7f1121 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevDbBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/DevDbBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Class which gets excluded if the configured value for 'db' is 'prodDB'

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTest.java
index bff4dc9..79008ae 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTest.java
@@ -39,7 +39,7 @@ import javax.enterprise.inject.spi.Extension;
 import java.net.URL;
 
 /**
- * Tests for {@link org.apache.deltaspike.core.api.exclude.Exclude}
+ * Tests for {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude}
  */
 @RunWith(Arquillian.class)
 public class ExcludeTest

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTestProjectStageDevelopment.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTestProjectStageDevelopment.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTestProjectStageDevelopment.java
index 9e583a1..f73a34d 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTestProjectStageDevelopment.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ExcludeTestProjectStageDevelopment.java
@@ -34,7 +34,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 
 /**
- * Tests for {@link org.apache.deltaspike.core.api.exclude.Exclude}
+ * Tests for {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude}
  */
 @RunWith(Arquillian.class)
 public class ExcludeTestProjectStageDevelopment

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/NoBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/NoBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/NoBean.java
index 2fa899d..9fb64ef 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/NoBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/NoBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Class which gets excluded in any case

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ProdDbBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ProdDbBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ProdDbBean.java
index 828ef9b..d31b976 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ProdDbBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/ProdDbBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Class which gets excluded if there is a configured value for the key called 'db' and

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/StdBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/StdBean.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/StdBean.java
index 190554a..b7acc33 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/StdBean.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/exclude/StdBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.test.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 import org.apache.deltaspike.core.api.projectstage.ProjectStage;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/MessageTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/MessageTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/MessageTest.java
index da7d0c1..f5a8e6b 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/MessageTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/MessageTest.java
@@ -36,7 +36,7 @@ import javax.inject.Inject;
 import static org.junit.Assert.assertEquals;
 
 /**
- * Tests for {@link org.apache.deltaspike.core.api.message.Message}
+ * Tests for {@link org.apache.deltaspike.core.api.message.annotation.Message}
  */
 @RunWith(Arquillian.class)
 public class MessageTest

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessage.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessage.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessage.java
index 90fa6d2..1781682 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessage.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessage.java
@@ -18,8 +18,10 @@
  */
 package org.apache.deltaspike.test.core.api.message;
 
-import org.apache.deltaspike.core.api.message.Message;
-import org.apache.deltaspike.core.api.message.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.Message;
+import org.apache.deltaspike.core.api.message.annotation.Message;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
 
 @MessageBundle
 public interface SimpleMessage

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessageTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessageTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessageTest.java
index 01d83fb..9d80a50 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessageTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/SimpleMessageTest.java
@@ -36,7 +36,7 @@ import javax.inject.Inject;
 import static org.junit.Assert.assertEquals;
 
 /**
- * Tests for {@link org.apache.deltaspike.core.api.message.Message}
+ * Tests for {@link org.apache.deltaspike.core.api.message.annotation.Message}
  */
 @RunWith(Arquillian.class)
 public class SimpleMessageTest

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/TestMessages.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/TestMessages.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/TestMessages.java
index b0c2b60..1c3c230 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/TestMessages.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/api/message/TestMessages.java
@@ -18,9 +18,12 @@
  */
 package org.apache.deltaspike.test.core.api.message;
 
-import org.apache.deltaspike.core.api.message.Message;
-import org.apache.deltaspike.core.api.message.MessageBundle;
-import org.apache.deltaspike.core.api.message.MessageContextConfig;
+import org.apache.deltaspike.core.api.message.annotation.Message;
+import org.apache.deltaspike.core.api.message.annotation.Message;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.MessageBundle;
+import org.apache.deltaspike.core.api.message.annotation.MessageContextConfig;
+import org.apache.deltaspike.core.api.message.annotation.MessageContextConfig;
 
 @MessageBundle
 @MessageContextConfig(messageInterpolator = TestMessageInterpolator.class)

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/ExcludeIntegrationTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/ExcludeIntegrationTest.java b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/ExcludeIntegrationTest.java
index 49b18dd..b74d669 100644
--- a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/ExcludeIntegrationTest.java
+++ b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/ExcludeIntegrationTest.java
@@ -46,7 +46,7 @@ import org.junit.runner.RunWith;
 import java.net.URL;
 
 /**
- * Integration tests for {@link org.apache.deltaspike.core.api.exclude.Exclude}
+ * Integration tests for {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude}
  */
 @RunWith(Arquillian.class)
 @Category(WebProfileCategory.class)

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestBean.java b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestBean.java
index 5503192..14b2fcd 100644
--- a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestBean.java
+++ b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.integration.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 import org.apache.deltaspike.core.api.projectstage.ProjectStage;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestDbBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestDbBean.java b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestDbBean.java
index 1a243df..b7dc84a 100644
--- a/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestDbBean.java
+++ b/deltaspike/core/integration-test/src/test/java/org/apache/deltaspike/integration/core/api/exclude/IntegrationTestDbBean.java
@@ -18,7 +18,7 @@
 */
 package org.apache.deltaspike.integration.core.api.exclude;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * Class which gets excluded if the configured value for 'db' is 'prodDB'

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2.java
----------------------------------------------------------------------
diff --git a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2.java b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2.java
index f3b86ee..ef012da 100644
--- a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2.java
+++ b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.example.config;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.util.Nonbinding;
 import javax.inject.Qualifier;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2WithInverseSupport.java
----------------------------------------------------------------------
diff --git a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2WithInverseSupport.java b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2WithInverseSupport.java
index a246fbd..55bb2b4 100644
--- a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2WithInverseSupport.java
+++ b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/Property2WithInverseSupport.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.example.config;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.util.Nonbinding;
 import javax.inject.Qualifier;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/SettingsBean.java
----------------------------------------------------------------------
diff --git a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/SettingsBean.java b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/SettingsBean.java
index e572ed8..698db9a 100644
--- a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/SettingsBean.java
+++ b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/config/SettingsBean.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.example.config;
 
-import org.apache.deltaspike.core.api.config.ConfigProperty;
+import org.apache.deltaspike.core.api.config.annotation.ConfigProperty;
 
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/echo/NoEchoService.java
----------------------------------------------------------------------
diff --git a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/echo/NoEchoService.java b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/echo/NoEchoService.java
index 6a916b9..83869f2 100644
--- a/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/echo/NoEchoService.java
+++ b/deltaspike/examples/jse-examples/src/main/java/org/apache/deltaspike/example/echo/NoEchoService.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.example.echo;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 /**
  * This implementation can't be used as CDI bean

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authentication/InMemoryUserStorage.java
----------------------------------------------------------------------
diff --git a/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authentication/InMemoryUserStorage.java b/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authentication/InMemoryUserStorage.java
index 1bc9134..6a89e7d 100644
--- a/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authentication/InMemoryUserStorage.java
+++ b/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authentication/InMemoryUserStorage.java
@@ -18,7 +18,7 @@
  */
 package org.apache.deltaspike.test.security.impl.authentication;
 
-import org.apache.deltaspike.core.api.exclude.Exclude;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exclude/ExcludeExtension.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exclude/ExcludeExtension.java
index c2fdee1..b4e2c83 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exclude/ExcludeExtension.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exclude/ExcludeExtension.java
@@ -19,9 +19,9 @@
 package org.apache.deltaspike.core.impl.exclude;
 
 import org.apache.deltaspike.core.api.config.ConfigResolver;
+import org.apache.deltaspike.core.api.exclude.annotation.Exclude;
 import org.apache.deltaspike.core.api.metadata.builder.AnnotatedTypeBuilder;
 import org.apache.deltaspike.core.spi.activation.Deactivatable;
-import org.apache.deltaspike.core.api.exclude.Exclude;
 import org.apache.deltaspike.core.api.interpreter.ExpressionInterpreter;
 import org.apache.deltaspike.core.api.projectstage.ProjectStage;
 import org.apache.deltaspike.core.impl.interpreter.PropertyExpressionInterpreter;
@@ -48,9 +48,9 @@ import java.util.logging.Logger;
 
 /**
  * <p>This class implements the logic for handling
- * {@link org.apache.deltaspike.core.api.exclude.Exclude} annotations.</p>
+ * {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude} annotations.</p>
  * <p/>
  * <p>Further details see {@link org.apache.deltaspike.core.api.exclude.Exclude}</p>
  */
 public class ExcludeExtension implements Extension, Deactivatable
 {

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/dd355a2b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/message/MessageBundleExtension.java
----------------------------------------------------------------------
@@ -48,9 +48,9 @@ import java.util.logging.Logger;
  * <p/>
- * <p>Further details see {@link org.apache.deltaspike.core.api.exclude.Exclude}</p>
+ * <p>Further details see {@link org.apache.deltaspike.core.api.exclude.annotation.Exclude}</p>
  */
 public class ExcludeExtension implements Extension, Deactivatable